#
# Conditional build:
%bcond_without	doc	# Sphinx documentation
%bcond_with	tests	# tornado tests [use network]

%define		module	tornado
Summary:	Web framework and asynchronous networking library
Summary(pl.UTF-8):	Szkielet WWW i asynchroniczna biblioteka sieciowa
Name:		python3-tornado
Version:	6.2
Release:	4
License:	Apache v2.0
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/tornado/
Source0:	https://files.pythonhosted.org/packages/source/t/tornado/tornado-%{version}.tar.gz
# Source0-md5:	32fbad606b439c3e1bf4e79d4e872741
Patch0:		asyncio-docs.patch
URL:		https://www.tornadoweb.org/
%if %{with python3}
BuildRequires:	python3-devel >= 1:3.7
BuildRequires:	python3-modules >= 1:3.7
BuildRequires:	python3-setuptools
%if %{with tests}
# SO_REUSEPORT option
BuildRequires:	uname(release) >= 3.9
BuildRequires:	python3-twisted
%endif
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
BuildRequires:	sed >= 4.0
%if %{with doc}
BuildRequires:	python3-sphinx_rtd_theme
BuildRequires:	python3-twisted
BuildRequires:	sphinx-pdg-3 >= 6
%endif
Requires:	python3-modules >= 1:3.7
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Tornado is a Python web framework and asynchronous networking library,
originally developed at FriendFeed. By using non-blocking network I/O,
Tornado can scale to tens of thousands of open connections, making it
ideal for long polling, WebSockets, and other applications that
require a long-lived connection to each user.

%description -l pl.UTF-8
Tornado to szkielet WWW oraz asynchroniczna biblioteka sieciowa dla
Pythona, oryginalnie powstałe w FriendFeed. Dzięki użyciu
nieblokującego sieciowego we/wy, Tornado może się skalować do
dziesiątek tysięcy otwartych połączeń, co czyni go idealnym do
zastosowań z długim pobieraniem, WebSockets i innych wymagających
długotrwałego połączenia z każdym użytkownikiem.

%package apidocs
Summary:	API documentation for Python tornado module
Summary(pl.UTF-8):	Dokumentacja API modułu Pythona tornado
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for Python tornado module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu Pythona tornado.

%prep
%setup -q -n tornado-%{version}
%patch -P0 -p1

%{__sed} -i -e '1s,/usr/bin/env python3\?,%{__python3},' demos/*/*.py

%build
TORNADO_EXTENSION=1 \
%py3_build

%if %{with tests}
cd build-3/lib*
%{__python3} -m tornado.test.runtests
cd ../..
%endif

%if %{with doc}
sphinx-build-3 -b html -n -d docs/build/doctrees docs docs/build/html
%endif

%install
rm -rf $RPM_BUILD_ROOT

%py3_install
# just tornado tests with their data
%{__rm} -r $RPM_BUILD_ROOT%{py3_sitedir}/tornado/test

install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -a demos/* $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README.rst
%dir %{py3_sitedir}/tornado
%attr(755,root,root) %{py3_sitedir}/tornado/speedups.abi3.so
%{py3_sitedir}/tornado/*.py
%{py3_sitedir}/tornado/py.typed
%{py3_sitedir}/tornado/platform
%{py3_sitedir}/tornado/__pycache__
%{py3_sitedir}/tornado-%{version}-py*.egg-info
%{_examplesdir}/%{name}-%{version}

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/build/html/{_images,_modules,_static,guide,releases,*.html,*.js}
%endif
%changelog
* Mon Apr 21 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python3-tornado.git;a=log;h=master

* Mon Apr 21 2025 Jan Palus <atler@pld-linux.org> 79d6278
- drop use of sphinxcontrib asyncio ext; rel 4

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> 9d1efc4
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> ab1d60f
- python 3.13 rebuild

* Mon Jan 02 2023 Jakub Bogusz <qboosh@pld-linux.org> 9a91f23
- python 3.7+ now

* Sun Jan 01 2023 Jakub Bogusz <qboosh@pld-linux.org> 66cd9d1
- updated to 6.2

* Sun Apr 03 2022 Jan Rękorajski <baggins@pld-linux.org> 6e8593f
- Release 5 (by relup.sh)

* Fri Apr 01 2022 Jan Rękorajski <baggins@pld-linux.org> 6f9308d
- Release 4 (by relup.sh)

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 1af1dbe
- rebuild with tests and docs

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 85f7a8a
- rebuild with python 3.10

* Mon Mar 14 2022 Jakub Bogusz <qboosh@pld-linux.org> 7d8205a
- updated to 6.1

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> 3fe8e45
- rebuild with separate debuginfo build-ids

* Mon Mar 01 2021 Jan Rękorajski <baggins@pld-linux.org> 92d5058
- release 2 (by relup.sh)

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 15f4066
- unconditional noarch subpackages

* Wed Mar 25 2020 Jakub Bogusz <qboosh@pld-linux.org> 9ede7d1
- resurrected, current versions are python3 only; updated to 6.0.4

* Mon Mar 28 2016 Jakub Bogusz <qboosh@pld-linux.org> 6e5e392
- see python-tornado.spec

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 58bf908
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> d87a09b
- automatic change: use py_build/py_install macros

* Sat Jul 28 2012 Jacek Konieczny <jajcus@jajcus.net> d4311f1
- URL fixed

* Tue Jul 24 2012 wrobell <wrobell@pld-linux.org> 3cf22d1
- rel. 1

* Tue Jul 24 2012 wrobell <wrobell@pld-linux.org> ce9c249
- cleanup: builds now

